Package: dStruct
Type: Package
Title: Identifying differentially reactive regions from RNA structurome
        profiling data
Version: 1.19.0
Depends: R (>= 4.1)
Authors@R: c(
    person("Krishna", "Choudhary", role=c("aut", "cre"), 
        email="kchoudhary@ucdavis.edu", comment = c(ORCID = "0000-0002-7966-1527")),
    person("Sharon", "Aviran", role=c("aut"), 
        email="saviran@ucdavis.edu", comment = c(ORCID = "0000-0003-1872-9820")))
Description: dStruct identifies differentially reactive regions from RNA structurome profiling data. dStruct is compatible with a broad range of structurome profiling technologies, e.g., SHAPE-MaP, DMS-MaPseq, Structure-Seq, SHAPE-Seq, etc. See Choudhary et al., Genome Biology, 2019 for the underlying method.
Imports: zoo, ggplot2, purrr, reshape2, parallel, IRanges, S4Vectors,
        rlang, grDevices, stats, utils
License: GPL (>= 2)
biocViews: StatisticalMethod, StructuralPrediction, Sequencing,
        Software
URL: https://github.com/dataMaster-Kris/dStruct
BugReports: https://github.com/dataMaster-Kris/dStruct/issues
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.1.1
Suggests: BiocStyle, knitr, rmarkdown, tidyverse, testthat (>= 3.0.0)
VignetteBuilder: knitr
Config/testthat/edition: 3
git_url: https://git.bioconductor.org/packages/dStruct
git_branch: devel
git_last_commit: 952c590
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 22:25:38 UTC; biocbuild
Author: Krishna Choudhary [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-7966-1527>),
  Sharon Aviran [aut] (ORCID: <https://orcid.org/0000-0003-1872-9820>)
Maintainer: Krishna Choudhary <kchoudhary@ucdavis.edu>
